@@ -1,5 +1,3 @@
-from urllib import response
-from numpy import uint
 from pymodbus.client.sync import ModbusTcpClient, ModbusSerialClient
 import struct 
 
